@@ -22,12 +22,12 @@ from Crypto.Hash import SHA384
 
 def deep_hash(data):
     if type(data) == list:
-        tag = b"list" + str(len(data)).encode()
+        tag = b'list' + str(len(data)).encode()
 
         return deep_hash_chunks(data, hashlib.sha384(tag).digest())
 
     else:
-        tag = b"blob" + str(len(data)).encode()
+        tag = b'blob' + str(len(data)).encode()
 
     tagged_hash = hashlib.sha384(tag).digest() + hashlib.sha384(data).digest()
 
